Module modules

Module modules 

Functions

parse_modules
The “modules” attribute declares the symbol to be used as the MODULES symbol, which enables the third modular state for all config symbols. At most one symbol may have the “modules” option set.