Functions
- parse_
optional - A choice entry accepts the attribute Optional, which allows to set the choice to ‘n’ and no entry needs to be selected. If no symbol is associated with a choice, then you can not have multiple definitions of that choice. If a Symbol is associated to the choice, then you may define the same choice (i.e. with the same entries) in another place.