Structs
- Range
- This attribute allows to limit the range of possible input values for int and hex symbols. The user can only input a value which is larger than or equal to the first symbol and smaller than or equal to the second symbol.
Enums
Functions
- parse_
range - Parses the
rangeattribute.