Struct nom_kconfig::attribute::range::Range
source · pub struct Range {
pub lhs: Symbol,
pub rhs: Symbol,
pub if: Option<Expression>,
}Expand description
This allows to limit the range of possible input values for int and hex symbols. The user can only input a value which is larger than or equal to the first symbol and smaller than or equal to the second symbol.
Fields
lhs: Symbolrhs: Symbolif: Option<Expression>Trait Implementations
sourceimpl<'de> Deserialize<'de> for Range
impl<'de> Deserialize<'de> for Range
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<Range> for Range
impl PartialEq<Range> for Range
impl StructuralPartialEq for Range