pub struct MainMenu {
pub prompt: String,
}Expand description
This sets the config program’s title bar if the config program chooses to use it. It should be placed at the top of the configuration, before any other statement.
Fields
prompt: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for MainMenu
impl<'de> Deserialize<'de> for MainMenu
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for MainMenu