Type Definition nom_kconfig::entry::menuconfig::MenuConfig
source · pub type MenuConfig = Config;Expand description
This is similar to the simple config entry, but it also gives a hint to front ends, that all suboptions should be displayed as a separate list of options. To make sure all the suboptions will really show up under the menuconfig entry and not outside of it, every item from the config options list must depend on the menuconfig symbol.