Module string

Module string 

Functions

parse_first_word
A first word is 'something here' or "something here" or just a normal word without spaces. It is used in places where Kconfig allows either a string or a symbol, such as in default attributes.
parse_string
take_until_unbalanced