parse_first_word

Function parse_first_word 

pub fn parse_first_word(
    input: KconfigInput<'_>,
) -> IResult<KconfigInput<'_>, KconfigInput<'_>>
A first word is 'something here' or "something here" or just a normal word without spaces. It is used in places where Kconfig allows either a string or a symbol, such as in default attributes.