Struct nom_kconfig::KconfigFile
source · pub struct KconfigFile { /* private fields */ }Expand description
Represents a Kconfig file.
It stores the kernel root directory because we need this information when a source keyword is met.
Implementations