Function nom_kconfig::attribute::help::parse_help
source · pub fn parse_help(input: KconfigInput<'_>) -> IResult<KconfigInput<'_>, String>Expand description
This parses a help text. The end of the help text is determined by the indentation level, this means it ends at the first line which has a smaller indentation than the first line of the help text.
Example
use nom_kconfig::{
assert_parsing_eq,
attribute::parse_help,
};
assert_parsing_eq!(parse_help, "help\n hello world", Ok(("", "hello world".to_string())))