Function nom_kconfig::attribute::optional::parse_optional
source · pub fn parse_optional(input: KconfigInput<'_>) -> IResult<KconfigInput<'_>, ()>Expand description
A choice accepts another option Optional, which allows to set the choice to ‘n’ and no entry needs to be selected. If no symbol is associated with a choice, then you can not have multiple definitions of that choice. If a Symbol is associated to the choice, then you may define the same choice (i.e. with the same entries) in another place.
Example
use nom_kconfig::{assert_parsing_eq, attribute::parse_optional};
assert_parsing_eq!(parse_optional, "optional", Ok(("", ())))